/* sdl_2.c
 * Ukazka programu v SDL
 * Jednoduse zobrazuje rybku
 *
 * Bernard Lidicky - 2004
 *
 * Je pod licenci GPL
 *
 * pro preklad mi fungovalo: "gcc sdl_2.c -o sdl_2 `sdl-config --cflags --static-libs`"
 */

#include <stdio.h>
#include <SDL.h>

SDL_Surface *screen; // obrazovka

// Zpracovana zpravy zasilane od SDL
int EventLoop()
{
	SDL_Event event;
	
	// z fronty zprav vybirame zpravy, dokut tam nejake jsou
	while ( SDL_PollEvent(&event) ) {
		switch (event.type) {
   
		// zprava s pozadavkem na ukonceni aplikace
		case SDL_QUIT :  
			return 0;
			break;
		}
	}
	
	return 1;
}

// Funkce main
int main( )
{
	SDL_Surface *ryba; // obrazek ryby
	SDL_Rect pozice;   // pozice ryby
	
	// Inicializace SDL a subsytemu s grafikou
	if ( SDL_Init(SDL_INIT_VIDEO) < 0 ) {
		fprintf(stderr, "Selhala inicializace SDL: %s\n", SDL_GetError());
		exit(1);
	}

	// Je vhodne pridat automaticke volani SDL_Quit pri ukonceni programu exitem
	atexit(SDL_Quit);

	// nastavime rozliseni okna a barevna hloubka nas nezajima
	if ( (screen = SDL_SetVideoMode(640, 480, 0, 0)) == NULL ) {
		fprintf(stderr, "Nepodarilo se vytvorit okno: %s\n", SDL_GetError());
		exit(2);
	}

	// nacteme obrazek ryby
	ryba = SDL_LoadBMP("ryba.bmp");
	if (ryba == NULL) {
		fprintf(stderr, "Nepodarilo se nacist ryba.bmp: %s\n", SDL_GetError());
		exit(2);
	}

	// nastavime, ze ruzova se nekresli
	if ( SDL_SetColorKey(ryba,  SDL_SRCCOLORKEY, SDL_MapRGB( ryba->format, 255, 0, 255)) < 0 ) {
		fprintf(stderr, "Nepodarilo se nastavit colorkey: %s\n", SDL_GetError());
		exit(2);
	}

	// priprava rectu
	pozice.x = 0;
	pozice.y = 0;
	pozice.w = ryba->w;
	pozice.h = ryba->h;
	
	
	// nejaka smycka zprav
	while ( EventLoop() ) {
	
		pozice.x++;
		pozice.y++;
	
		if ( pozice.y > 480 ) break;	
		
		// vymazeme obrazovku do svetle modre
		SDL_FillRect(screen, NULL,  SDL_MapRGB( screen->format, 80, 180, 250));
		
		//	nakreslime rybu
		SDL_BlitSurface(ryba, NULL, screen, &pozice);

		
		// aktualizujeme obrazovku
		SDL_UpdateRect(screen, 0, 0, 640, 480);
	}

	// uvolnime obrazek ryby
	SDL_FreeSurface(ryba);

	
	// ukonceni SDL
	SDL_Quit();
	
	return 0;
}
