/* sdl_5.c
 * Ukazka programu v SDL
 * Umoznuje ovladani rybky
 *
 * Bernard Lidicky - 2004
 *
 * Je pod licenci GPL
 *
 * pro preklad mi fungovalo: "gcc sdl_5.c -o sdl_5 `sdl-config --cflags --static-libs`"
 */

#include <stdio.h>
#include <SDL.h>

// nastaveni rozliseni 
// V normalni hre by se melo nacotat z konfiguracniho souboru
#define SCREEN_X   640
#define SCREEN_Y   480
#define SCREEN_BPP   0 // 0 == nezajima nas

SDL_Surface   *screen; // obrazovka
Uint8            *key; // buffer klavesnice
int           mouse_x; // mys x
int           mouse_y; // mys y



SDL_Surface *ryba; // obrazek ryby
SDL_Rect   pozice; // pozice ryby

float r, g, b;    // barva rgb
float dr, dg, db; // zmena barvy


/*
 * Provede inicializaci knihovny, nastavi rozliseni
 */
void InitSystem()
{
	
	// Inicializace SDL a subsytemu s grafikou
	if ( SDL_Init(SDL_INIT_VIDEO) < 0 ) {
		fprintf(stderr, "Selhala inicializace SDL: %s\n", SDL_GetError());
		exit(1);
	}

	// Je vhodne pridat automaticke volani SDL_Quit pri ukonceni programu exitem
	atexit(SDL_Quit);

	// nastavime rozliseni okna a barevna hloubka nas nezajima
	if ( (screen = SDL_SetVideoMode(SCREEN_X, SCREEN_Y, SCREEN_BPP, 0)) == NULL ) {
		fprintf(stderr, "Nepodarilo se vytvorit okno: %s\n", SDL_GetError());
		exit(2);
	}


}

/*
 * Provede na konci programu uklid
 */   
void CleanAll()
{
	// uvolnime obrazek ryby
	SDL_FreeSurface(ryba);

	
	// ukonceni SDL
	SDL_Quit();
}

/*
 * Nacte bitmapy a podobne veci
 */
void InitGame()
{

	// nacteme obrazek ryby
	ryba = SDL_LoadBMP("ryba.bmp");
	if (ryba == NULL) {
		fprintf(stderr, "Nepodarilo se nacist ryba.bmp: %s\n", SDL_GetError());
		exit(2);
	}

	// nastavime, ze ruzova se nekresli
	if ( SDL_SetColorKey(ryba,  SDL_SRCCOLORKEY, SDL_MapRGB( ryba->format, 255, 0, 255)) < 0 ) {
		fprintf(stderr, "Nepodarilo se nastavit colorkey: %s\n", SDL_GetError());
		exit(2);
	}

	// priprava rectu
	pozice.x = SCREEN_X/2;
	pozice.y = SCREEN_Y/2;
	pozice.w = ryba->w;
	pozice.h = ryba->h;

	// barcika pozadi
	r = 0;
	g = 0;
	b = 0;

	// meneni barvy podkladu]
	dr = 0.2;
	dg = 0.5;
	db = 0.7;
}	


/*
 *  Zpracovana zpravy zasilane od SDL
 */
int EventLoop()
{
	SDL_Event event;
	
	// z fronty zprav vybirame zpravy, dokut tam nejake jsou
	while ( SDL_PollEvent(&event) ) {
		switch (event.type) {
   
		// zprava s pozadavkem na ukonceni aplikace
		case SDL_QUIT :  
			return 0;
			break;
		}
	}
	
	return 1;
}






// Funkce main
int main( )
{
        // inicializace SDL
	InitSystem();
	
	// nacteni bitmapek a podobne
	InitGame();

	

	// prvni cteni stavu klavesnice
	key = SDL_GetKeyState(NULL);
	                 	
	// nejaka smycka zprav
	while ( EventLoop() &&  (key[SDLK_q] == 0)) {
	
		// cteni stavu klavesnice
		key = SDL_GetKeyState(NULL);
		
		// pohybova cast
		if ( key[SDLK_LEFT] )  pozice.x--;
		if ( key[SDLK_RIGHT] ) pozice.x++;
		if ( key[SDLK_UP] )    pozice.y--;
		if ( key[SDLK_DOWN] )  pozice.y++;

		// omezeni pohybu
		if ( pozice.x < 0) pozice.x += SCREEN_X;
		if ( pozice.y < 0) pozice.y += SCREEN_Y;
		if ( pozice.x > SCREEN_X) pozice.x -= SCREEN_X;
		if ( pozice.y > SCREEN_Y) pozice.y -= SCREEN_Y;
		
		
		// pohyb pres mys
		if ( SDL_GetMouseState(&mouse_x, &mouse_y) & SDL_BUTTON_LEFT ) {
			pozice.x = mouse_x;
			pozice.y = mouse_y;
		}

	
		// zmena barevneho podlozi
		if ( (r += dr) > 255 ) r = 0;
		if ( (g += dg) > 255 ) g = 0;
		if ( (b += db) > 255 ) b = 0;
		
		
		
		// kreslici cast
		
		// vymazeme obrazovku
		SDL_FillRect(screen, NULL,  SDL_MapRGB( screen->format, r, g, b));
		
		// nakreslime rybu
		SDL_BlitSurface(ryba, NULL, screen, &pozice);
		
		
		// aktualizujeme obrazovku - 4 nuly == vsechno
		SDL_UpdateRect(screen, 0, 0, 0, 0);
	}
	return 0;
}
