/* sdl_7.c
 * Ukazka programu v SDL
 * Zobrazuje animovaneho ptaka 
 *
 * Bernard Lidicky - 2004
 *
 * Je pod licenci GPL
 *
 * pro preklad mi fungovalo: "gcc sdl_7.c -o sdl_7 `sdl-config --cflags --static-libs`"
 */

#include <stdio.h>
#include <SDL.h>

// nastaveni rozliseni 
// V normalni hre by se melo nacotat z konfiguracniho souboru
#define SCREEN_X   640
#define SCREEN_Y   480
#define SCREEN_BPP   0 // 0 == nezajima nas

SDL_Surface *screen; // obrazovka

SDL_Surface *ptak; // obrazek ptaka
SDL_Rect   pozice; // pozice ptaka
SDL_Rect   anim_rec;   // obdelnik v animaci
int        anim;   // aktualni cislo animacniho okenka

/*
 * Provede inicializaci knihovny, nastavi rozliseni
 */
void InitSystem()
{
	
	// Inicializace SDL a subsytemu s grafikou
	if ( SDL_Init(SDL_INIT_VIDEO|SDL_DOUBLEBUF) < 0 ) {
		fprintf(stderr, "Selhala inicializace SDL: %s\n", SDL_GetError());
		exit(1);
	}

	// Je vhodne pridat automaticke volani SDL_Quit pri ukonceni programu exitem
	atexit(SDL_Quit);

	// nastavime rozliseni okna a barevna hloubka nas nezajima
	if ( (screen = SDL_SetVideoMode(SCREEN_X, SCREEN_Y, SCREEN_BPP, 0)) == NULL ) {
		fprintf(stderr, "Nepodarilo se vytvorit okno: %s\n", SDL_GetError());
		exit(2);
	}


}

/*
 * Provede na konci programu uklid
 */   
void CleanAll()
{
	// uvolnime obrazek ryby
	SDL_FreeSurface(ptak);

	
	// ukonceni SDL
	SDL_Quit();
}

/*
 * Nacte bitmapy a podobne veci
 */
void InitGame()
{

	// nacteme obrazek ryby
	ptak = SDL_LoadBMP("ptak.bmp");
	if (ptak == NULL) {
		fprintf(stderr, "Nepodarilo se nacist ptak.bmp: %s\n", SDL_GetError());
		exit(2);
	}

	// nastavime, ze ruzova se nekresli
	if ( SDL_SetColorKey(ptak,  SDL_SRCCOLORKEY, SDL_MapRGB( ptak->format, 255, 0, 255)) < 0 ) {
		fprintf(stderr, "Nepodarilo se nastavit colorkey: %s\n", SDL_GetError());
		exit(2);
	}

	// priprava rectu
	anim_rec.x = 0;
	anim_rec.y = 0;
	anim_rec.w = pozice.w = ptak->w;
	anim_rec.h = pozice.h = 68;

	// pozice ptaka na obrazovce
	pozice.x = 50;
	pozice.y = 250;
	
	anim = 0;
	
}	

/*
 *  Zpracovana zpravy zasilane od SDL
 */
int EventLoop()
{
	SDL_Event event;
	
	// z fronty zprav vybirame zpravy, dokut tam nejake jsou
	while ( SDL_PollEvent(&event) ) {
		switch (event.type) {
   
		// zprava s pozadavkem na ukonceni aplikace
		case SDL_QUIT :  
			return 0;
			break;
		}
	}
	
	return 1;
}






// Funkce main
int main( )
{
	int time1, time2; // mereni casu

        // inicializace SDL
	InitSystem();
	
	// nacteni bitmapek a podobne
	InitGame();
	
	time1 = SDL_GetTicks();
	time2 = SDL_GetTicks();
	
	
	// nejaka smycka zprav
	while ( EventLoop() ) {
	
		// zjistime minimalni spozdeni 200 ms
		while ( time1 - time2 < 200 )  time1 = SDL_GetTicks();
		time2 = time1;
	
		// vymazeme obrazovku do svetle modre
		SDL_FillRect(screen, NULL,  SDL_MapRGB( screen->format, 80, 180, 250));
		
		// posuneme cykl animace a pripadne zacyklime animaci
		if ( ++anim > 6 ) anim = 0;
		
		// prepocitame aktualni obrelnik podle animace
		anim_rec.y = 69 * anim;

		
		SDL_BlitSurface(ptak, &anim_rec, screen, &pozice);
		
		// aktualizujeme obrazovku
		SDL_Flip(screen);
	}

	// uklid
	CleanAll();
	
	return 0;
}
